import Vue from 'vue';
import Router from 'vue-router';

Vue.use(Router)

/* Layout */
import Layout from '@/layout'
import { getMenu } from '@/utils/auth.js';

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
    {
        path: '/login',
        component: () => import('@/views/login/index'),
        hidden: true
    },

    {
        path: '/404',
        component: () => import('@/views/404'),
        hidden: true
    },

    {
        path: '/',
        component: Layout,
        redirect: '/home',
        hidden: true,
        meta: { title: '机票管理', icon: 'home', affix: true },
        children: [
            {
                path: 'home',
                component: () => import('@/views/airplan//airplan_book/airplan_book.vue'),
                name: 'Dashboard',
                meta: { title: '机票预订', icon: 'dashboard', affix: true }
            }
        ]
    },

    {
        path: '/order',
        component: Layout,
        hidden: true,
        children: [
            {
                path: 'detail',
                component: () => import('@/views/order/order_detail/order_detail.vue'),
                name: 'orderDetail',
                meta: { title: '订单详情', icon: '', affix: false }
            }
        ]
    },

    {
        path: '/airplano',
        component: Layout,
        hidden: true,
        children: [
            {
                path: 'airplanoriderdetail',
                component: () => import('@/views/airplan/airplan_order/airplan_order_detail/airplan_order_detail.vue'),
                name: 'airplanoriderdetail',
                meta: { title: '订单详情', icon: '', affix: false }
            }
        ]
    },

    {
        path: '/airbook',
        component: Layout,
        hidden: true,
        children: [
            {
                path: 'airbookdetail',
                component: () => import('@/views/airplan/airplan_book/book_detail/book_detail.vue'),
                name: 'airbookdetail',
                meta: { title: '机票预订', icon: '', affix: false }
            }
        ]
    },

    {
        path: '/pay',
        component: Layout,
        hidden: true,
        children: [
            {
                path: 'orderdetail',
                component: () => import('@/views/airplan/airplan_book/order_detail/order_detail.vue'),
                name: 'orderdetail',
                meta: { title: '机票支付', icon: '', affix: false }
            },
            {
                path: 'payresult',
                component: () => import('@/views/airplan/pay_result/pay_result.vue'),
                name: 'payresult',
                meta: { title: '支付结果', icon: '', affix: false }
            }
        ]
    },

    // {
    //     path: '/pay',
    //     component: Layout,
    //     hidden: true,
    //     children: [
    //         {
    //             path: 'payresult',
    //             component: () => import('@/views/airplan/pay_result/pay_result.vue'),
    //             name: 'payresult',
    //             meta: { title: '支付结果', icon: '', affix: false }
    //         }
    //     ]
    // },
]

const createRouter = () => new Router({
    mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
    const newRouter = createRouter()
    router.matcher = newRouter.matcher // reset router
}

export default router
