import { constantRoutes } from '@/router'
import Layout from '@/layout'

export function filterRoutes(menus){
    let menu = menus;
    let routers = [];
    if ( !menu ) return [];

    menu.forEach( item => {
        if ( item.menuUrl === '/train' ) return;

        // 设置基础管理
        let _router = {
            path: item.menuUrl,
            component: Layout,
            name: item.menuUrl.split('/')[1],
            meta: { title: item.menuName, noCache: true }
        };

        // 设置菜单大项左侧的图标
        if ( item.menuUrl === '/basics' ) _router.meta.icon = 'el-icon-s-help';
        else if ( item.menuUrl === '/system' ) _router.meta.icon = 'el-icon-s-tools';
        else if ( item.menuUrl === '/money' ) _router.meta.icon = 'el-icon-s-goods';
        else if ( item.menuUrl === '/msgAdministration' ) _router.meta.icon = 'el-icon-s-comment';
        else if ( item.menuUrl === '/train' ) _router.meta.icon = 'el-icon-s-ticket';
        else if ( item.menuUrl === '/airplan' ) _router.meta.icon = 'el-icon-s-promotion';
        else if ( item.menuUrl === '/orderManage' ) _router.meta.icon = 'el-icon-s-order';
        else {}

        // 设置菜单子项
        let children = [];
        item.childMenus.forEach( cItem => {
            let _child = {
                path: cItem.menuUrl,
                name: cItem.menuUrl.split('/')[1],
                meta: { title: cItem.menuName, icon: 'el-icon-s-unfold', noCache: true }
            }

            if ( cItem.menuUrl === '/role' ) {
                _child.component = () => import( /* webpackChunkName: "basic_role" */ '@/views/basic/basic_role/basic_role.vue' );
            }
            else if ( cItem.menuUrl === '/menu' ) {
                _child.component = () => import( /* webpackChunkName: "basic_menu" */ '@/views/basic/basic_menu/basic_menu.vue' );
            }

            else if ( cItem.menuUrl === '/businessMoney' ) {
                _child.component = () => import( /* webpackChunkName: "business_bag" */ '@/views/system/business_bag/business_bag.vue' );
            }
            else if ( cItem.menuUrl === '/myselfMoney' ) {
                _child.component = () => import( /* webpackChunkName: "person_bag" */ '@/views/system/person_bag/person_bag.vue' );
            }
            else if ( cItem.menuUrl === '/permission' ) {
                _child.component = () => import( /* webpackChunkName: "business_manage" */ '@/views/system/business_manage/business_manage.vue' );
            }
            else if ( cItem.menuUrl === '/personnel' ) {
                _child.component = () => import( /* webpackChunkName: "person_manage" */ '@/views/system/person_manage/person_manage.vue' );
            }
            
            else if ( cItem.menuUrl === '/rechargeList' ) {
                _child.component = () => import( /* webpackChunkName: "recharte_list" */ '@/views/money/recharte_list/recharte_list.vue' );
            }            
            else if ( cItem.menuUrl === '/paylogLlist' ) {
                _child.component = () => import( /* webpackChunkName: "pay_log" */ '@/views/money/pay_log/pay_log.vue' );
            }            
            else if ( cItem.menuUrl === '/dealList' ) {
                _child.component = () => import( /* webpackChunkName: "deal_log" */ '@/views/money/deal_log/deal_log.vue' );
            }            
            else if ( cItem.menuUrl === '/recharge' ) {
                _child.component = () => import( /* webpackChunkName: "recharge" */ '@/views/money/recharge/recharge.vue' );
            }            
            else if ( cItem.menuUrl === '/myselfMoneys' ) {
                _child.component = () => import( /* webpackChunkName: "user_bag" */ '@/views/money/user_bag/user_bag.vue' );
            }  
                      
            else if ( cItem.menuUrl === '/meselfMsg' ) {
                _child.component = () => import( /* webpackChunkName: "personal_info" */ '@/views/info/personal_info/personal_info.vue' );
            } 
                      
            else if ( cItem.menuUrl === '/home' ) {
                _child.component = () => import( /* webpackChunkName: "airplan_book" */ '@/views/airplan/airplan_book/airplan_book.vue' );
            }            
            else if ( cItem.menuUrl === '/airorder' ) {
                _child.component = () => import( /* webpackChunkName: "airplan_order" */ '@/views/airplan/airplan_order/airplan_order.vue' );
            }           
            else if ( cItem.menuUrl === '/airorderWrite' ) {
                _child.component = () => import( /* webpackChunkName: "airplan_enter" */ '@/views/airplan/airplan_enter/airplan_enter.vue' );
            }    
            else if ( cItem.menuUrl === '/myOrder' ) {
                _child.component = () => import( /* webpackChunkName: "order_list" */ '@/views/order/order_list/order_list.vue' );
            }
            else if ( cItem.menuUrl === '/orderedit' ) {
                _child.component = () => import( /* webpackChunkName: "order_edit" */ '@/views/order/order_edit/order_edit.vue' );
            }
            else if ( cItem.menuUrl === '/orderrebook' ) {
                _child.component = () => import( /* webpackChunkName: "order_rebook" */ '@/views/order/order_rebook/order_rebook.vue' );
            }
            else if ( cItem.menuUrl === '/orderrefund' ) {
                _child.component = () => import( /* webpackChunkName: "order_refund" */ '@/views/order/order_refund/order_refund.vue' );
            }
            else {}

            children.push(_child);
        });
        _router.children = children;
        routers.push(_router);
    });
    routers.push({ path: '*', redirect: '/404', hidden: true });
    return routers;
}

const state = {
    routes: [],
    addRoutes: [],
    hasAddRoutes: false
}

const mutations = {
    SET_ROUTES: (state, routes) => {
        state.addRoutes = routes
        state.routes = constantRoutes.concat(routes)
    },
    SET_ISADDROUTES: (state, flag) => {
        state.hasAddRoutes = flag
    },
}

const actions = {
    generateRoutes({ commit }, menu) {
        return new Promise(resolve => {
            let accessedRoutes = [];
            accessedRoutes = filterRoutes(JSON.parse(menu))
            commit('SET_ROUTES', accessedRoutes)
            resolve(accessedRoutes)
        })
    },

    hasAddRoutes({ commit }, flag) {
        return new Promise(resolve => {
            commit('SET_ISADDROUTES', flag)
            resolve(flag)
        })
    },
}

export default {
    namespaced: true,
    state,
    mutations,
    actions
}
