import { login, logout, getInfo } from '@/api/user.js';
import { getToken, setToken, removeToken } from '@/utils/auth.js';
import { getMenu, setMenu, removeMenu } from '@/utils/auth.js';
import { getName, setName, removeName } from '@/utils/auth.js';
import { resetRouter } from '@/router';
import store from '../index.js';

const getDefaultState = () => {
    return {
        token: getToken(),
        menu: getMenu(),
        name: getName(),
        avatar: ''
    }
}

const state = getDefaultState()

const mutations = {
    RESET_STATE: (state) => {
        Object.assign(state, getDefaultState());
    },

    SET_TOKEN: (state, token) => {
        state.token = token;
    },

    SET_NAME: (state, name) => {
        state.name = name;
    },

    SET_AVATAR: (state, avatar) => {
        state.avatar = avatar;
    },

    SET_MENU: (state, data) => {
        state.menu = data;
    },
}

const actions = {
    // user login
    login({ commit }, userInfo) {
        const { userName, password } = userInfo
        return new Promise((resolve, reject) => {
            login({ userName: userName.trim(), password: password }).then(response => {
                const { data } = response;
                // 保存token
                commit('SET_TOKEN', data.token);
                setToken(data.token);

                // 保存菜单列表
                commit('SET_MENU', JSON.stringify(data.menus));
                setMenu(JSON.stringify(data.menus));

                // 保存用户名
                commit('SET_NAME', userName);
                setName(userName);

                resolve();
            }).catch(error => {
                reject(error);
            })
        })
    },

    // get user info
    getInfo({ commit, state }) {
        return new Promise((resolve, reject) => {
            getInfo(state.token).then(response => {
                const { data } = response

                if (!data) {
                    return reject('Verification failed, please Login again.')
                }

                const { name, avatar } = data

                commit('SET_NAME', name)
                commit('SET_AVATAR', avatar)
                resolve(data)
            }).catch(error => {
                reject(error)
            })
        })
    },

    // user logout
    logout({ commit, state }) {
        return new Promise((resolve, reject) => {
            store.dispatch('permission/hasAddRoutes', false)
            removeToken(); // must remove  token  first
            removeMenu();
            removeName();
            resetRouter()
            commit('RESET_STATE')
            resolve();
        })
    },

    // remove token
    resetToken({ commit }) {
        return new Promise(resolve => {
            removeToken() // must remove  token  first
            commit('RESET_STATE')
            resolve()
        })
    }
}

export default {
    namespaced: true,
    state,
    mutations,
    actions
}

