import moment from 'moment';
import ticketBook from '@/components/tab_select/tab_select.vue';
import { ticketLineList, ticketPriceList } from '@/api/ticket.js';

export default {
    name: 'AriplanBook',

    data() {
        return {
            // 加载菊花
            loading: false,
            // 选择的机票类型
            ticketType: '1',
            startDate: moment().format("YYYY-MM-DD"),
            backDate: '',
            // 日历配置项
            pickerOptions: {
                disabledDate(time) {
                    return time.getTime() < moment().subtract(1, "days");
                }
            },
            // 根据用户选择查询出来的机票列表
            airlineList: [],
            // 订票按钮的箭头图片
            arrowIcon: 'el-icon-arrow-down',
            // 用于保存表格展开时的机票价格信息
            airPriceList: [],
            tableLoadingList: [],
            // 航空公司图标地址
            airIcon: ''
        };
    },
    methods: {
        /**
         * 查询机票
         */
        queryAbleTickets() {
            // 判断用户填写
            if ( !this.$refs.start.choosedItatCode ) {
                this.$message({ type: 'warning', message: '请选择出发地' });
                return;
            }
            else if ( !this.$refs.end.choosedItatCode ) {
                this.$message({ type: 'warning', message: '请选择目的地' });
                return;
            }
            else if ( !this.startDate ) {
                this.$message({ type: 'warning', message: '请选择出发日期' });
                return;
            }
            else {}

            let reqData = {
                depCity: this.$refs.start.choosedItatCode,
                arrCity: this.$refs.end.choosedItatCode,
                depDate: this.startDate,
                flightType: this.ticketType
            };

            sessionStorage.setItem('fromCity', this.$refs.start.choosedCity.split('(')[0]);
            sessionStorage.setItem('toCity', this.$refs.end.choosedCity.split('(')[0]);
            this.loading = true;
            ticketLineList(reqData).then( res => {
                this.loading = false;
                if ( res.data.length === 0 ) this.$message({ type: 'warning', message: '当前没有合适的航班' });
                this.airlineList = res.data;
            }).catch( err => {
                console.log(err);
                this.loading = false;
            });
        },

        /**
         * 控制表格行的展开和收缩
         */
        toogleExpand(row, index) {
            let $table = this.$refs.airlineTable;
            $table.toggleRowExpansion(row);
            let reqData = { depCity: row.depCity, arrCity: row.arrCity, depDate: row.depTime.split(' ')[0], flightNo: row.flightNo };

            this.$set( this.tableLoadingList, index, true );
            ticketPriceList(reqData).then( res => {
                this.$set( this.tableLoadingList, index, false );
                this.airPriceList[index] = res.data;
            }).catch( err => {
                console.log(err);
                this.$set( this.tableLoadingList, index, false );
            });
        },

        /**
         * 跳转到订机票详情页
         */
        toBookDetail(row, parentRow) {
            sessionStorage.setItem('bk', row.bk);
            sessionStorage.setItem('ticketFull', JSON.stringify(parentRow));
            sessionStorage.setItem('ticketSelected', JSON.stringify(row));
            this.$router.push({
                path: '/airbook/airbookdetail',
                query: { svopId: row.svopId }
            });
        },


        airIconUrl(data) {
            if ( !data.flightNo ) return '';

            let iconName = `${data.flightNo.substr(0, 2)}.gif`;
            let imgurl = require(`../../../assets/airIcons/${iconName}`);
            return imgurl;
        }
    },

    components: {
        ticketBook: ticketBook
    }
};
