import moment from 'moment';
import { ticketPreCheck, ticketCreateOrder } from '@/api/ticket.js';

export default {
    name: 'BookDetail',

    data() {
        return {
            // 加载菊花
            loading: false,
            // 机票总体信息
            ticketInfo: {},
            // 选中的机票信息
            ticketSelected: {},
            // 买票的乘客列表
            passengerList: [{ name: '', ageType: '0', cardType: 'NI', cardNo: '', phoneNumber: '', sex: '0' }],
            // 乘客联系人
            contractData: { contact: '', contactMob: '' },
            // 乘客信息样式
            passItemStyle: { width: '210px' },
            // 机场建设费
            airFee: 50,
            reserveData: {},
            checkedList: [ false ]
        };
    },

    mounted() {
        // 机票校验
        this.preCheck();

        // 机票总体信息
        this.ticketInfo = JSON.parse(sessionStorage.getItem('ticketFull'));

        // 选中的机票信息
        this.ticketSelected = JSON.parse(sessionStorage.getItem('ticketSelected'));
    },

    computed: {
        ticketWeekday(obj) {
            let CHNWeek = ['日', '一', '二', '三', '四', '五', '六']
            return CHNWeek[moment(obj.ticketInfo.depTime).day()]; 
        },

        totalCharge(obj) {
            return (parseFloat(obj.ticketSelected.finalPrice) + parseFloat(obj.airFee)) * obj.passengerList.length;
        }
    },  

    methods: {
        /**
         * 预定前的机票校验
         */
        preCheck() {
            let reqData = { svopId: this.$route.query.svopId, bk: sessionStorage.getItem('bk') };

            this.loading = true;
            ticketPreCheck(reqData).then( res => {
                this.loading = false;
                this.reserveData = res.data;
            }).catch( err => {
                this.loading = false;
            });
        },

        /**
         * 添加乘客
         */
        addPass() {
            this.passengerList.push({ name: '', ageType: '0', cardType: 'NI', cardNo: '', phone: '', sex: '0' });
            this.checkedList.push(false);
        },

        /**
         * 删除乘客
         */
        removePass(index) {
            this.passengerList.splice( index , 1 );
            this.checkedList.splice( index , 1 );
        },

        /**
         * 准备提交预订
         */
        submitBook() {
            this.$confirm('是否确认提订单?', '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning'
            }).then( () => {
                this.submitBookData();
            }).catch( () => {});
        },

        /**
         * 提交订单数据到api
         */
        submitBookData() {
            this.passengerList.forEach( item => {
                item.barePrice = this.ticketSelected.price;
                item.cabin = this.ticketSelected.cabins;
                item.constructionFee = this.airFee;
                item.discount = this.ticketInfo.discounts;
                item.fuelTax = '0';
                item.salePrice = this.ticketSelected.finalPrice;
                item.contactMob = item.phone;
            });

            let reqData = {
                address: '',
                airCompanyName: this.ticketInfo.carrierName,
                arrAirPort: this.ticketInfo.arrCityName,
                arrCity: sessionStorage.getItem('toCity'),
                arrTime: this.ticketInfo.arrTime,
                barePrice: this.ticketSelected.price,
                cabin: this.ticketSelected.cabins,
                constructionFee: this.airFee,
                contact: this.contractData.contact,
                contactMob: this.contractData.contactMob,
                contactPreNum: '86',
                datasource: this.reserveData.datasource,
                depAirPort: this.ticketInfo.depCityName,
                deptCity: sessionStorage.getItem('fromCity'),
                detTime: this.ticketInfo.depTime,
                discount: this.ticketInfo.discounts,
                flightNo: this.ticketInfo.flightNo,
                flightType: '1',
                fuelTax: '0',
                param: this.reserveData.param,
                passengersList: this.passengerList,
                salePrice: this.ticketSelected.finalPrice,
                sjr: '',
                stop: 0,
                bk: sessionStorage.getItem('bk'),
                svopId: this.$route.query.svopId
            };

            this.loading = true;
            ticketCreateOrder(reqData).then( res => {
                this.loading = false;
                this.$message({ type: 'success', message: '机票订单提交成功' });
                sessionStorage.setItem('payData', JSON.stringify(res.data));
                this.$router.replace({
                    path: '/pay/orderdetail',
                    query: { orderid: res.data.orderId, svopId: this.$route.query.svopId }
                });
            }).catch( err => {
                this.loading = false;
            });
        }
    }
};
