import { ticketOrderPayDetail, ticketPreCheck } from '@/api/ticket.js';
import { bagPayFinal, bagPayFinalByYeepay } from '@/api/bag.js';

export default {
    name: 'OrderDetail',

    data() {
        return {
            // 加载菊花
            loading: false,
            // 机票支付信息
            ticketPayData: [{}],
            // 乘客信息
            passengerList: [],
            payRadio: 'bag'
        };
    },

    computed: {
        totalPrice(obj) {
            let total = 0;
            obj.passengerList.forEach( item => {
                total = total + parseFloat(item.salePrice) + parseFloat(item.constructionFee);
            });

            return this.$money(total);
        }
    },

    mounted() {
        this.getOrderDetail();
    },

    methods: {
        /**
         * 获取订单详情
         */
        getOrderDetail() {
            this.ticketPayData = [JSON.parse(sessionStorage.getItem('payData'))];
            this.passengerList = JSON.parse(sessionStorage.getItem('payData')).passengerList;
        },

        /**
         * 支付确认
         */
        confirmPay() {
            let payType = this.payRadio === 'bag' ? '钱包支付' : '易宝支付';

            let tip = `
                您将使用<span style="color: #06388a; font-weight: bold; font-size: 16px;">${payType}</span>，
                支付金额：<span style="color: #06388a; font-weight: bold; font-size: 16px;">${this.totalPrice}</span> 元
            `;

            this.$confirm(tip, '确认', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning',
                dangerouslyUseHTMLString: true
            }).then( () => {
                let reqData = { svopId: this.$route.query.svopId, bk: sessionStorage.getItem('bk') };

                this.loading = true;
                ticketPreCheck(reqData).then( res => {
                    this.loading = false;
                
                    if ( this.payRadio === 'bag' ) this.submitBookData();
                    else if ( this.payRadio === 'yibao' ) this.submitPayByYibao();
                    else {}
                }).catch( err => {
                    this.loading = false;
                });
            }).catch( () => {});
        },

        /**
         * 使用钱包支付
         */
        submitBookData() {
            let reqData = { orderId: this.ticketPayData[0].orderId };

            this.loading = true;
            bagPayFinal(reqData).then( res => {
                this.$message({ type: 'success', message: '支付成功' });
                this.loading = false;
                this.closePaypage('/pay/orderdetail');
                this.$router.replace({ 
                    path: '/pay/payresult', 
                    query: { orderId: this.ticketPayData[0].orderId }
                });
            }).catch( err => {
                this.loading = false;
            });
        },

        /**
         * 使用易宝支付
         */
        submitPayByYibao() {
            let reqData = { orderId: this.ticketPayData[0].orderId };

            this.loading = true;
            bagPayFinalByYeepay(reqData).then( res => {
                this.loading = false;
                window.location.href = res.data;
            }).catch( err => {
                this.loading = false;
            });
        },

        /**
         * 关闭支付页面，防止重复支付
         */
        closePaypage(toCloseTagPath) {
            let tags = this.$store.state.tagsView.visitedViews;
            let currentTag = tags.find( item => item.path === toCloseTagPath );

            this.$store.dispatch('tagsView/delView', currentTag).then(({ visitedViews }) => {});
        }
    }
};
