import { ticketAirplanLine, ticketDeleteOrder } from '@/api/ticket.js';

export default {
    name: 'AriplanOrder',

    data() {
        return {
            // 加载菊花
            loading: false,
            // 数据列表
            dataList: [],
            // 过滤数据
            filterData: {},            
            // 分页的页数
            pageNum: 1,
            // 每页展示的数据条数
            pageSize: 10,
            // 数据总数
            totalCount: 0,
        };
    },

    mounted() {
        // 获取数据列表
        this.getDataList(this.filterData);
    },

    methods: {
        /**
         * 获取数据列表
         * @return none
         */
        getDataList(filter) {
            let reqData = { pageNum: this.pageNum, pageSize: this.pageSize, ...filter };

            this.loading = true;
            ticketAirplanLine(reqData).then( res => {
                this.loading = false;
                this.dataList = res.data.list;
                this.totalCount = res.data.total;
            }).catch( err => {
                this.loading = false;
                console.log(err);
            });
        },

        /**
         * 数据列表换页
         */
        toPage(page) {
            this.pageNum = page;
            this.getDataList(this.filterData);
        },

        /**
         * 查询数据
         */
        queryData(type) {
            if ( type == 1 ) this.pageNum = 1;
            this.getDataList(this.filterData);
        },

        /**
         * 新增订单
         */
        createOrder() {
            this.$router.push({ 
                path: '/airplano/airplanoriderdetail',
                query: { type: 2 }
            });
        },

        /**
         * 跳转到订单详情
         */
        toDetailPage(row) {
            this.$router.push({ 
                path: '/airplano/airplanoriderdetail',
                query: { orderid: row.orderId, type: 1 }
            });
        },

        /**
         * 删除机票订单
         */
        deleteAriOrder(row) {
            this.$confirm(`是否确认删除该订单<b style="color: red;">(${row.orderId})</b>?`, '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning',
                dangerouslyUseHTMLString: true
            }).then( () => {
                let reqData = { id: row.id, orderId: row.orderId };
                this.loading = true;
                ticketDeleteOrder(reqData).then( res => {
                    this.$message({ type: 'success', message: '订单已删除' });
                    this.loading = false;
                    this.getDataList(this.filterData);
                }).catch( err => {
                    console.log(err);
                    this.loading = false;
                });
            }).catch( () => {});
        }
    }
};
