import { basicMenuList, setMenu, basicDeleteMenu } from '@/api/basic.js';

export default {
	name: 'BasicMenu',

	data() {
		return {
            // 加载菊花
            loading: false,
            // 数据列表
            dataList: [],
            // 过滤数据
            filterData: {},
            // 显示新增菜单窗口
            showAddMenuDlg: false,
            // 弹窗title
            dlgTitle: '',
            // 新增或修改的菜单信息
            menuData: {},
            // 弹窗中确认按钮菊花
            confirmLoading: false,
            // 当前正在修改的表格行数据
            currentRow: {},
		}
	},

    mounted() {
        // 获取数据列表
        this.getDataList(this.filterData);
    },

    methods: {
        /**
         * 获取数据列表
         * @return none
         */
        getDataList(filter) {
            let reqData = {};

            this.loading = true;
            basicMenuList(reqData).then( res => {
                this.loading = false;
                this.dataList = res.data;
            }).catch( err => {
                this.loading = false;
                console.log(err);
            });
        },

        /**
         * 打开新增菜单
         */
        addRole() {
            this.dlgTitle = '新增菜单';
            this.showAddMenuDlg = true;
        },

        /**
         * 新增子菜单
         */
        showMenuDialog(row) {
            this.dlgTitle = '新增子菜单';
            this.showAddMenuDlg = true;
            this.currentRow = JSON.parse(JSON.stringify(row));
        },

        /**
         * 修改菜单
         */
        editMenu(row) {
            this.dlgTitle = '修改菜单';
            this.showAddMenuDlg = true;
            this.currentRow = JSON.parse(JSON.stringify(row));
            this.menuData = this.currentRow;
        },

        /**
         * 删除菜单
         */
        deleteMenu(row) {
            this.currentRow = JSON.parse(JSON.stringify(row));
            this.$confirm(`是否确认删除菜单: <b style="color: red;">${row.menuName}</b>?`, '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning',
                dangerouslyUseHTMLString: true
            }).then( () => {
                this._submitDeleteMenu(row);
            }).catch( () => {});
        },

        /**
         * 提交删除到后台
         */
        _submitDeleteMenu(data) {
            let reqData = { id: data.id };

            basicDeleteMenu(reqData).then( res => {
                this.$message({ type: 'success', message: '删除菜单成功' });
                this.getDataList(this.filterData);
            }).catch( err => {});
        },

        /**
         * 取消菜单
         */
        cancelMenu() {
            this.showAddMenuDlg = false;
            this.menuData = {};
            this.confirmLoading = false;
        },

        /**
         * 确定提交菜单
         */
        confirmMenu() {
            // 判断用户填写
            if ( !this.menuData.menuName ) {
                this.$message({ type: 'warning', message: '请输入菜单名称' });
                return;
            }
            else if ( !this.menuData.menuUrl ) {
                this.$message({ type: 'warning', message: '请输入菜单路由' });
                return;
            }
            else if ( !this.menuData.menuSort ) {
                this.$message({ type: 'warning', message: '请输入菜单顺序' });
                return;
            }
            else {}

            // 提交菜单信息
            this.dlgTitle === '新增菜单' && this._submitRole();
            this.dlgTitle === '新增子菜单' && this._submitRole(this.currentRow);
            this.dlgTitle === '修改菜单' && this._submitRole(this.currentRow);
        },

        /**
         * 提交角色数据到后台
         */
        _submitRole(data) {
            let reqData = JSON.parse(JSON.stringify(this.menuData));
            reqData.parentId = '';
            if ( this.dlgTitle === '新增子菜单' ) reqData.parentId = data.id;
            if ( this.dlgTitle === '修改菜单' ) {
                reqData.id = data.id;
                reqData.parentId = data.parentId ? data.parentId : '';
            } 

            this.confirmLoading = true;
            setMenu(reqData).then( res => {
                this.confirmLoading = false;
                this.showAddMenuDlg = false;
                this.menuData = {};
                this.$message({ type: 'success', message: `${this.dlgTitle}成功` });
                this.getDataList(this.filterData);
            }).catch( err => {
                this.confirmLoading = false;
                console.log(err);
            });
        },
    }
};
