import { basicRoleList, setRole, deleteRole, basicMenuList, basicRolePermission } from '@/api/basic.js';

export default {
    name: 'BasicRole',

    data() {
        return {
            // 加载菊花
            loading: false,
            // 数据列表
            dataList: [{}, {}, {}],
            // 过滤数据
            filterData: {},            
            // 分页的页数
            pageNum: 1,
            // 每页展示的数据条数
            pageSize: 10,
            // 数据总数
            totalCount: 0,
            // 显示新增角色窗口
            showAddRoleDlg: false,
            // 弹窗title
            dlgTitle: '',
            // 弹窗中确认按钮菊花
            confirmLoading: false,
            // 新增或修改的角色数据
            roleData: {},
            // 当前正在修改的表格行数据
            currentRow: {},
            // 显示分配菜单弹窗
            showMenuDlg: false,
            // 带单列表
            menuList: [],
            defaultProps: {
                children: 'childMenus',
                label: 'menuName'
            },
            // 选中的角色分配的菜单
            menuOfRole: []
        }
    },

    mounted() {
        // 获取数据列表
        this.getDataList(this.filterData);

        // 获取菜单列表
        this.getMenuList();
    },

    methods: {
        /**
         * 获取数据列表
         * @return none
         */
        getDataList(filter) {
            let reqData = { pageNum: this.pageNum, pageSize: this.pageSize };

            this.loading = true;
            basicRoleList(reqData).then( res => {
                this.loading = false;
                this.dataList = res.data.list;
                this.totalCount = res.data.total;
            }).catch( err => {
                this.loading = false;
                console.log(err);
            });
        },

        /**
         * 数据列表换页
         */
        toPage(page) {
            this.pageNum = page;
            this.getDataList(this.filterData);
        },

        /**
         * 新增角色
         */
        addRole() {
            this.dlgTitle = '新增角色';
            this.showAddRoleDlg = true;
        },

        /**
         * 修改角色
         */
        editRole(row) {
            this.dlgTitle = '修改角色';
            this.currentRow = JSON.parse(JSON.stringify(row));
            this.roleData = { roleName: row.roleName, roleDesc: row.roleDesc };
            this.showAddRoleDlg = true;
        },

        /**
         * 确定新增或修改角色
         */
        confirmRole() {
            // 判断用户填写
            if ( !this.roleData.roleName ) {
                this.$message({ type: 'warning', message: '请输入角色名称' });
                return;
            }
            else if ( !this.roleData.roleDesc ) {
                this.$message({ type: 'warning', message: '请输入角色描述' });
                return;
            }
            else {}

            // 提交角色信息
            this.dlgTitle === '新增角色' && this._submitRole();
            this.dlgTitle === '修改角色' && this._submitRole(this.currentRow);
        },

        /**
         * 提交角色数据到后台
         */
        _submitRole(data) {
            let reqData = JSON.parse(JSON.stringify(this.roleData));
            if ( data ) reqData.id = data.id;

            this.confirmLoading = true;
            setRole(reqData).then( res => {
                this.confirmLoading = false;
                this.showAddRoleDlg = false;
                this.$message({ type: 'success', message: `${data && data.id ? '修改' : '新增'}角色成功` });
                this.pageNum = 1;
                this.getDataList(this.filterData);
            }).catch( err => {
                this.confirmLoading = false;
                console.log(err);
            });
        },

        /**
         * 取消角色操作
         */
        cancelRole() {
            this.showAddRoleDlg = false;
            this.roleData = {};
            this.confirmLoading = false;
        },

        /**
         * 删除角色
         */
        deleteRole(row) {
            this.$confirm(`是否确认删除角色: <b style="color: red;">${row.roleName}</b>?`, '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning',
                dangerouslyUseHTMLString: true
            }).then( () => {
                this._submitDeleteRole(row);
            }).catch( () => {});
        },

        /**
         * 提交删除到后台
         */
        _submitDeleteRole(data) {
            let reqData = { id: data.id };

            deleteRole(reqData).then( res => {
                this.$message({ type: 'success', message: '删除角色成功' });
                this.pageNum = 1;
                this.getDataList(this.filterData);
            }).catch( err => {});
        },

        /**
         * 获取菜单列表
         */
        getMenuList() {
            let reqData = {};

            basicMenuList({}).then( res => {
                this.menuList = res.data;
            }).catch( err => {  
                console.log(err);
            });
        },

        /**
         * 打开分菜单窗口
         */
        showMenuDialog(row) {
            this.currentRow = JSON.parse(JSON.stringify(row));
            this.menuOfRole = row.currentMenus ? row.currentMenus.split(',') : [];
            this.showMenuDlg = true;
        },

        /**
         * 取消分配菜单
         */
        cancelMenu() {
            this.showMenuDlg = false;
            this.$refs.tree.setCheckedKeys([]);
        },

        /**
         * 确定分配菜单
         */
        confirmMenu() {
            let reqData = { id: this.currentRow.id, menuIds: this.$refs.tree.getCheckedKeys() };

            this.confirmLoading = true;
            basicRolePermission(reqData).then( res => {
                this.confirmLoading = false;
                this.showMenuDlg = false;
                this.$message({ type: 'success', message: '分配菜单成功' });
                this.pageNum = 1;
                this.getDataList(this.filterData);
            }).catch( err => {
                console.log(err);
                this.confirmLoading = false;
            });
        }
    }
};
