import axios from 'axios';
import { bagPayApply } from '@/api/bag.js';

export default {
    name: 'Recharge',

    data() {
        return {
            // 加载菊花
            loading: false,
            // 充值数据
            payData: {},
            // 提交菊花
            confirmLoading: false,
            // 预览图片地址
            imageUrl: '',
            // 图片上传到服务器后生成的路径
            imageCloudPath: ''
        };
    },

    methods: {
        /**
         * 提交充值申请
         */
        submitApp() {
            // 判断用户填写
            if ( !this.imageUrl ) {
                this.$message({ type: 'warning', message: '请上传图片' });
                return;
            }
            else if ( !this.payData.addType ) {
                this.$message({ type: 'warning', message: '请填写支付方式' });
                return;
            }
            else if ( !this.payData.addmoney ) {
                this.$message({ type: 'warning', message: '请填写充值金额' });
                return;
            }
            else if ( !this.payData.remark ) {
                this.$message({ type: 'warning', message: '请填写备注' });
                return;
            }
            else {}

            this.$confirm('是否确认提交充值申请?', '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning'
            }).then( () => {
                let reqData = { addImg: this.imageCloudPath, ...this.payData };
                this.loading = true;
                bagPayApply(reqData).then( res => {
                    this.$message({ type: 'success', message: '充值申请提交成功' });
                    this.loading = false;
                    this.payData = {};
                    this.imageCloudPath = '';
                    this.imageUrl = '';
                }).catch( err => {
                    console.log(err);
                    this.loading = false;
                });
            }).catch( () => {});

        },

        uploadFile(e) {
            let file = e.file;


            if ( !['image/jpeg', 'image/png'].includes(file.type) ) {
                this.$message({ type: 'error', message: '请上传jpg或png格式图片' });
                this.imageUrl = '';
                return;
            }

            let formData = new FormData();
            // let token = 'true';
            // formData.append('token', token);
            formData.append('file', file);

            this.loading = true;
            axios({
                headers: { 'Content-Type': 'multipart/form-data' },
                method: 'post',
                url: 'http://120.77.203.53:19000/api/purse/upload/picture',
                data: formData
            }).then( res => {
                this.loading = false;
                this.imageCloudPath = res.data.data;
            }).catch( err => {});
        },

        onSuccess(file) {
            this.imageUrl = URL.createObjectURL(file.raw);
        }
    }
};
