import { bagPayList, bagPay } from '@/api/bag.js';

export default {
	name: 'RechargeList',

	data() {
		return {
            // 加载菊花
            loading: false,
            // 数据列表
            dataList: [],
            // 过滤数据
            filterData: {},            
            // 分页的页数
            pageNum: 1,
            // 每页展示的数据条数
            pageSize: 10,
            // 数据总数
            totalCount: 0,
            // 显示充值窗口
            showPayDlg: false,
            // 弹窗中确认按钮菊花
            confirmLoading: false,
            // 充值数据
            payData: {}
		};
	},

    mounted() {
        // 获取数据列表
        this.getDataList(this.filterData);
    },

    methods: {
        /**
         * 获取数据列表
         * @return none
         */
        getDataList(filter) {
            let reqData = { pageNum: this.pageNum, pageSize: this.pageSize };
            if ( filter ) {
                reqData.status = filter.status;  // 账号
            }

            this.loading = true;
            bagPayList(reqData).then( res => {
                this.loading = false;
                this.dataList = res.data.list;
                this.totalCount = res.data.total;
            }).catch( err => {
                this.loading = false;
                console.log(err);
            });
        },

        /**
         * 查询数据
         */
        queryData() {
            this.pageNum = 1;
            this.getDataList(this.filterData);
        },

        /**
         * 数据列表换页
         */
        toPage(page) {
            this.pageNum = page;
            this.getDataList(this.filterData);
        },

        /**
         * 
         */
        setPay(row) {
            this.payData = JSON.parse(JSON.stringify(row));
        	this.showPayDlg = true;
        },

        /**
         * 取消设置角色
         */
        cancelPay() {
            this.payData = {};
            this.showPayDlg = false;
        },

        /**
         * 确定设置角色
         */
        confirmPay() {
            if ( !this.payData.addType ) {
                this.$message({ type: 'warning', message: '请输入支付方式' });
                return;
            }
            else if ( !this.payData.addmoney ) {
                this.$message({ type: 'warning', message: '请输入充值金额' });
                return;
            }
            else if ( !this.payData.returnMoney ) {
                this.$message({ type: 'warning', message: '请输入返利金额' });
                return;
            }
            else {}

            let reqData = { 
                id: this.payData.id, 
                addImg: this.payData.addImg,
                addType: this.payData.addType,
                companyId: this.payData.companyId,
                userId: this.payData.userId,
                addMoney: this.payData.addmoney,
                returnMoney: this.payData.returnMoney
            };

            this.confirmLoading = true;
            bagPay(reqData).then( res => {
                this.confirmLoading = false;
                this.showPayDlg = false;
                this.payData = {};
                this.$message({ type: 'success', message: '充值成功' });
                this.pageNum = 1;
                this.getDataList(this.filterData);
            }).catch( err => {
                console.log(err);
                this.confirmLoading = false;
            });
        },
    }
};
