import { orderGetList } from '@/api/order.js';

export default {
    name: 'OrderList',

    data() {
        return {
            // 加载菊花
            loading: false,
            // 数据列表
            dataList: [],
            // 过滤数据
            filterData: {},            
            // 分页的页数
            pageNum: 1,
            // 每页展示的数据条数
            pageSize: 10,
            // 数据总数
            totalCount: 0,
        };
    },

    mounted() {
        // 获取数据列表
        this.getDataList(this.filterData);
    },

    methods: {
        /**
         * 获取数据列表
         * @return none
         */
        getDataList(filter) {
            let reqData = { pageNum: this.pageNum, pageSize: this.pageSize };
            if ( filter ) {
                reqData.orderStatus = filter.orderStatus;  // 订单状态
                reqData.orderId = filter.orderId;  // 订单号
            }

            this.loading = true;
            orderGetList(reqData).then( res => {
                this.loading = false;
                this.dataList = res.data.list;
                this.totalCount = res.data.total;
            }).catch( err => {
                this.loading = false;
                console.log(err);
            });
        },

        /**
         * 数据列表换页
         */
        toPage(page) {
            this.pageNum = page;
            this.getDataList(this.filterData);
        },

        /**
         * 查询数据
         */
        queryData() {
            this.pageNum = 1;
            this.getDataList(this.filterData);
        },

        /**
         * 重置数据
         */
        resetData() {
            this.pageNum = 1;
            this.filterData = {};
            this.getDataList(this.filterData);
        },

        setOrder(row, type) {
            sessionStorage.setItem('bk', row.bk);

            this.$router.push({
                path: '/order/detail',
                query: { type: type, orderId: row.orderId, svopId: row.svopId }
            });
        },

        /**
         * 改变每页显示条数事件
         */
        handleSizeChange(val) {
            this.pageSize = val;
            this.pageNum = 1;
            this.getDataList(this.filterData);
        }
    }
};
