import { basicMenuList } from '@/api/basic.js';
import { systemCompanyList, systemSetMenu, systemSetCompany } from '@/api/system.js';

export default {
	name: 'BusinessManage',

	data() {
		return {
            // 加载菊花
            loading: false,
            // 数据列表
            dataList: [],
            // 过滤数据
            filterData: {},            
            // 分页的页数
            pageNum: 1,
            // 每页展示的数据条数
            pageSize: 10,
            // 数据总数
            totalCount: 0,
            // 显示分配菜单弹窗
            showMenuDlg: false,
            // 弹窗中确认按钮菊花
            confirmLoading: false,
            // 当前正在修改的表格行数据
            currentRow: {},
            // 带单列表
            menuList: [],
            defaultProps: {
                children: 'childMenus',
                label: 'menuName'
            },
            // 选中的角色分配的菜单
            menuOfRole: []
		};
	},

    mounted() {
        // 获取数据列表
        this.getDataList(this.filterData);

        // 获取菜单列表
        this.getMenuList();
    },

    methods: {
        /**
         * 获取数据列表
         * @return none
         */
        getDataList(filter) {
            let reqData = { pageNum: this.pageNum, pageSize: this.pageSize };
            if ( filter ) {
            	reqData.companyName = filter.companyName;
            	reqData.companyStatus = filter.companyStatus;
            }

            this.loading = true;
            systemCompanyList(reqData).then( res => {
                this.loading = false;
                this.dataList = res.data.list;
                this.totalCount = res.data.total;
            }).catch( err => {
                this.loading = false;
                console.log(err);
            });
        },

        /**
         * 获取菜单列表
         */
        getMenuList() {
            let reqData = {};

            basicMenuList({}).then( res => {
                this.menuList = res.data;
            }).catch( err => {  
                console.log(err);
            });
        },

        /**
         * 数据列表换页
         */
        toPage(page) {
            this.pageNum = page;
            this.getDataList(this.filterData);
        },

        /**
         * 打开分菜单窗口
         */
        showMenuDialog(row) {
            this.currentRow = JSON.parse(JSON.stringify(row));
            this.menuOfRole = row.currentMenus ? row.currentMenus.split(',') : [];
            this.menuOfRole.forEach( (item, index) => {
            	this.menuOfRole[index] = parseInt(item).toString();
            });
            this.showMenuDlg = true;
        },

        /**
         * 取消分配菜单
         */
        cancelMenu() {
            this.showMenuDlg = false;
            this.$refs.tree.setCheckedKeys([]);
        },

        /**
         * 确定分配菜单
         */
        confirmMenu() {
            let reqData = { id: this.currentRow.id, menuIds: this.$refs.tree.getCheckedKeys() };

            this.confirmLoading = true;
            systemSetMenu(reqData).then( res => {
                this.confirmLoading = false;
                this.showMenuDlg = false;
                this.$message({ type: 'success', message: '分配菜单成功' });
                this.pageNum = 1;
                this.getDataList(this.filterData);
            }).catch( err => {
                console.log(err);
                this.confirmLoading = false;
            });
        },

        /**
         * 审核操作
         */
        setCompany(row, status) {
        	let tip = '';
        	if ( status == 0 ) tip = '是否确认删除商家';
        	else if ( status == 2 ) tip = '是否确认审批通过，商家';
        	else if ( status == 3 ) tip = '是否确认审批驳回，商家';
        	else {}

            this.$confirm(`${tip}: <b style="color: red;">${row.companyName}</b>?`, '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning',
                dangerouslyUseHTMLString: true
            }).then( () => {
                this._submitDeleteRole(row, status);
            }).catch( () => {});
        },

        /**
         * 提交审核信息到后台
         */
        _submitDeleteRole(data, status) {
            let reqData = { id: data.id, companyStatus: status, userId: data.userId };
            if ( status == 2 ) {
            	reqData.menuIds = [1];
	            data.currentMenus && data.currentMenus.split(',').forEach( (item, index) => {
	            	reqData.menuIds[index] = parseInt(item).toString();
	            });
            }

            systemSetCompany(reqData).then( res => {
                this.$message({ type: 'success', message: '提交成功' });
                this.pageNum = 1;
                this.getDataList(this.filterData);
            }).catch( err => {});
        },

        /**
         * 查询数据
         */
        queryData() {
            this.pageNum = 1;
        	this.getDataList(this.filterData);
        },

        /**
         * 重置数据
         */
        resetData() {
        	this.pageNum = 1;
        	this.filterData = {};
        	this.getDataList(this.filterData);
        }
    }
};
