import { systemUserBagList, systemSetBagStatus } from '@/api/system.js';

export default {
	name: 'PersonBag',

	data() {
		return {
            // 加载菊花
            loading: false,
            // 数据列表
            dataList: [],
            // 过滤数据
            filterData: {},            
            // 分页的页数
            pageNum: 1,
            // 每页展示的数据条数
            pageSize: 10,
            // 数据总数
            totalCount: 0,
		};
	},

    mounted() {
        // 获取数据列表
        this.getDataList(this.filterData);
    },

    methods: {
        /**
         * 获取数据列表
         * @return none
         */
        getDataList(filter) {
            let reqData = { pageNum: this.pageNum, pageSize: this.pageSize };

            this.loading = true;
            systemUserBagList(reqData).then( res => {
                this.loading = false;
                this.dataList = res.data;
                this.totalCount = res.data.total;
            }).catch( err => {
                this.loading = false;
                console.log(err);
            });
        },

        /**
         * 设置钱包状态
         */
        setBagStatus(row) {
        	let tip = `是否确认${row.status == 1 ? '关闭' : '打开'}该用户钱包?`

            this.$confirm(tip, '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning'
            }).then( () => {
	        	let reqData = {
	        		id: row.purseId,
	        		type: 'user',
	        		userId: row.id,
	        		companyId: row.companyId,
	        		accountName: row.nickName,
	        		balancemoney: row.balancemoney,
	        		totlemoney: row.totlemoney,
	        		userdmoney: row.userdmoney,
	        		totalreturnmoney: row.totalreturnmoney,
	        		status: row.status == 1 ? 0 : 1
	        	};

	        	this.loading = true;
	        	systemSetBagStatus(reqData).then( res => {
	        		this.$message({ type: 'success', message: row.status == 1 ? '关闭钱包成功' : '打开钱包成功' });
	        		this.getDataList(this.filterData);
	        	}).then( err => {
	        		this.loading = false;
	        		console.log(err);
	        	});
            }).catch( () => {});
        }
    }
};
