import { systemUserList, systemSetUserStatus, systemSetUserRole } from '@/api/system.js';
import { basicRoleList } from '@/api/basic.js';

export default {
    name: 'PersonManage',

    data() {
        return {
            // 加载菊花
            loading: false,
            // 数据列表
            dataList: [],
            // 过滤数据
            filterData: {},            
            // 分页的页数
            pageNum: 1,
            // 每页展示的数据条数
            pageSize: 10,
            // 数据总数
            totalCount: 0,
            // 显示分配菜单弹窗
            showMenuDlg: false,
            // 弹窗中确认按钮菊花
            confirmLoading: false,
            // 显示分配菜单弹窗,
            userRoleList: [],
            // 选择分配给用户的角色
            choosedRole: { role: [] },
            // 当前正在修改的表格行数据
            currentRow: {}
        };
    },

    mounted() {
        // 获取数据列表
        this.getDataList(this.filterData);

        // 获取角色列表
        this.getRoleList();
    },

    methods: {
        /**
         * 获取数据列表
         * @return none
         */
        getDataList(filter) {
            let reqData = { pageNum: this.pageNum, pageSize: this.pageSize };
            if ( filter ) {
                reqData.userName = filter.userName;  // 账号
                reqData.nickName = filter.nickName;  // 昵称
                reqData.mobileNum = filter.mobileNum;  // 手机号
                reqData.userStatus = filter.userStatus;  // 用户状态
            }

            this.loading = true;
            systemUserList(reqData).then( res => {
                this.loading = false;
                this.dataList = res.data.list;
                this.totalCount = res.data.total;
            }).catch( err => {
                this.loading = false;
                console.log(err);
            });
        },

        /**
         * 重置数据
         */
        resetData() {
            this.pageNum = 1;
            this.filterData = {};
            this.getDataList(this.filterData);
        },

        /**
         * 查询数据
         */
        queryData() {
            this.pageNum = 1;
            this.getDataList(this.filterData);
        },

        /**
         * 数据列表换页
         */
        toPage(page) {
            this.pageNum = page;
            this.getDataList(this.filterData);
        },

        /**
         * 设置账号停用或启用
         */
        setAccount( row, status ) {
            let tip = status == 1 ? '停用' : '启用';

            this.$confirm(`是否${tip}该账号(<b style="color: red;">${row.userName}</b>)?`, '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning',
                dangerouslyUseHTMLString: true
            }).then( () => {
                this._setRoleStatus(row, status);
            }).catch( () => {});
        },

        /**
         * 提交账号设置
         */
        _setRoleStatus(row, status) {
            let reqData = { id: row.id, userStatus: status };

            systemSetUserStatus(reqData).then( res => {
                this.$message({ type: 'success', message: '提交成功' });
                this.pageNum = 1;
                this.getDataList(this.filterData);
            }).catch( err => {});
        },        

        /**
         * 获取菜单列表
         */
        getRoleList() {
            let reqData = {};
 
            basicRoleList({}).then( res => {
                this.userRoleList = res.data.list;
            }).catch( err => {  
                console.log(err);
            });
        },

        /**
         * 设置角色状态
         */
         setAccountStauts(row) {
            this.currentRow = JSON.parse(JSON.stringify(row));
            this.choosedRole.role = row.roleId ? row.roleId.split(',').map(Number) : [];
            this.showMenuDlg = true;
         },

        /**
         * 取消设置角色
         */
        cancelMenu() {
            this.currentRow = {};
            this.showMenuDlg = false;
            this.choosedRole = { role: [] };
        },

        /**
         * 确定设置角色
         */
        confirmMenu() {
            if ( !this.choosedRole.role ) {
                this.$message({ type: 'warning', message: '请选择要分配给用户的角色' });
                return;
            }

            let reqData = { id: this.currentRow.id, roleIds: this.choosedRole.role };
            this.confirmLoading = true;
            systemSetUserRole(reqData).then( res => {
                this.confirmLoading = false;
                this.showMenuDlg = false;
                this.choosedRole = { role: [] };
                this.$message({ type: 'success', message: '分配角色成功' });
                this.pageNum = 1;
                this.getDataList(this.filterData);
            }).catch( err => {
                console.log(err);
                this.confirmLoading = false;
            });
        },
    }


};
